==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/mi-NZ/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Kei te tīariari tetahi pūkete ki tenei īmēra.',
    'account_not_found'      => 'He hē te ingoa kaiwhakamahi, kupuhipa rānei.',
    'account_not_activated'  => 'Kāore tēnei pūkete kaiwhakamahi i te whakahohea.',
    'account_suspended'      => 'Kua tohua tenei pūkete kaiwhakamahi.',
    'account_banned'         => 'Ka whakatakahia tenei pūkete kaiwhakamahi.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'Kua uru koe ki roto.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
    ),

    'signin' => array(
        'error'   => 'I te raruraru i te wa e ngana ana ki te takiuru ki a koe, tena koa ngana ano.',
        'success' => 'Kua uru koe ki roto.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'I te raruraru i te wa e ngana ana ki te hanga i to taakete, me ngana ano.',
        'success' => 'Ko te kaute i hanga.',
    ),

    'forgot-password' => array(
        'error'   => 'He raru i te wa e ngana ana ki te tautuhi i te waehere kupuhipa, me ngana ano.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'He raruraru i te wa e ngana ana ki te tautuhi i to kupuhipa, ngana ano.',
        'success' => 'Kua oti te tautuhi i to kupuhipa.',
    ),


);

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/mi-NZ/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Kei te tīariari tetahi pūkete ki tenei īmēra.',
    'account_not_found'      => 'He hē te ingoa kaiwhakamahi, kupuhipa rānei.',
    'account_not_activated'  => 'Kāore tēnei pūkete kaiwhakamahi i te whakahohea.',
    'account_suspended'      => 'Kua tohua tenei pūkete kaiwhakamahi.',
    'account_banned'         => 'Ka whakatakahia tenei pūkete kaiwhakamahi.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'Kua uru koe ki roto.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
        'enter_two_factor_code' => 'Please enter your two-factor authentication code.',
        'please_enroll'         => 'Please enroll a device in two-factor authentication.',
    ),

    'signin' => array(
        'error'   => 'I te raruraru i te wa e ngana ana ki te takiuru ki a koe, tena koa ngana ano.',
        'success' => 'Kua uru koe ki roto.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'I te raruraru i te wa e ngana ana ki te hanga i to taakete, me ngana ano.',
        'success' => 'Ko te kaute i hanga.',
    ),

    'forgot-password' => array(
        'error'   => 'He raru i te wa e ngana ana ki te tautuhi i te waehere kupuhipa, me ngana ano.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'He raruraru i te wa e ngana ana ki te tautuhi i to kupuhipa, ngana ano.',
        'success' => 'Kua oti te tautuhi i to kupuhipa.',
    ),


);
